"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/* eslint-disable unicorn/no-array-push-push */
/* eslint-disable unicorn/import-style */
const core_1 = require("@oclif/core");
const util = require('util');
const accountUris = require("../../../helpers/uris");
const anypoint_cli_command_1 = require("anypoint-cli-command");
const flags_1 = require("anypoint-cli-command/lib/core/flags");
class Describe extends anypoint_cli_command_1.AuthenticationBaseCommand {
    async run() {
        const { args } = await this.parse(Describe);
        await this.businessGroupDescribe(args.identifier);
    }
    async businessGroupDescribe(identifier) {
        const session = this.session;
        let org;
        if (identifier === '') {
            org = session.selectedOrganization.id;
        }
        else {
            const user = await this.req.get(anypoint_cli_command_1.uris.userMe);
            const orgs = user.data.memberOfOrganizations;
            org = orgs.find((org) => {
                if (org.id === identifier) {
                    return true;
                }
                return false;
            });
            if (!org) {
                org = orgs.find((org) => {
                    if (org.name === identifier) {
                        return true;
                    }
                    return false;
                });
            }
            if (!org) {
                this.error(new Error(`Organization ${identifier} not found`));
            }
            org = org.id;
        }
        await this.businessGroupDescribeRequest(org, session);
    }
    async businessGroupDescribeRequest(organizationId, session) {
        const organizationRequest = await this.req.get(accountUris.organization(organizationId));
        const organizationData = organizationRequest.data;
        let owner;
        if (organizationData.owner && organizationData.owner.id === session.account.user.id) {
            owner = organizationData.owner.username;
        }
        else {
            owner = false;
            delete (organizationData.owner);
        }
        const tableData = [];
        tableData.push(['Name', organizationData.name], ['Owner', owner ? owner : 'You do not have permission to see this info'], ['Type', organizationData.isRoot ? 'Root' : 'Business unit']);
        if (organizationData.subscription) {
            tableData.push(['Subscription', util.format('Category: %s\nType: %s\nExpires: %s', organizationData.subscription.category, organizationData.subscription.type, organizationData.subscription.expiration || 'never')]);
        }
        tableData.push(['Environments', organizationData.environments.map((env) => {
                return env.name;
            })]);
        tableData.push(['Entitlements', util.inspect(organizationData.entitlements, { colors: true })]);
        await this.show(tableData, organizationData);
    }
}
exports.default = Describe;
Describe.args = [
    {
        name: 'identifier',
        default: '',
    },
];
Describe.description = 'Show details of a business group. If "identifier" is omitted, defaults to the current session\'s business group.' +
    'Identifier searches for id match first, then name.';
Describe.flags = {
    ...anypoint_cli_command_1.AuthenticationBaseCommand.flags,
    help: core_1.Flags.help({ char: 'h' }),
    ...flags_1.OutputFlag,
};
