"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/* eslint-disable unicorn/no-array-push-push */
const core_1 = require("@oclif/core");
const anypoint_cli_command_1 = require("anypoint-cli-command");
const flags_1 = require("anypoint-cli-command/lib/core/flags");
const envTypes = new Set(['design', 'production', 'sandbox']);
class Create extends anypoint_cli_command_1.AuthenticationBaseCommand {
    async run() {
        const { args, flags } = await this.parse(Create);
        await this.environmentCreate(args.name, flags.type);
    }
    async environmentCreate(name, type) {
        const body = {
            name: name,
            type: '',
            organizationId: '',
        };
        const session = this.session;
        body.organizationId = session.selectedOrganization.id;
        const flagType = type ? type : 'sandbox';
        if (envTypes.has(flagType)) {
            body.type = flagType;
        }
        else {
            this.error(new Error(`--type flag value ${type} unsupported`));
        }
        await this.environmentCreateRequest(session, body);
    }
    async environmentCreateRequest(session, body) {
        var _a, _b;
        try {
            const { status, data } = await this.req.post(anypoint_cli_command_1.uris.environments(session.selectedOrganization.id), body);
            if (status === 201) {
                this.log(`Environment ${data.name} created`);
                const tableData = [];
                tableData.push(['Id', data.id]);
                tableData.push(['Name', data.name]);
                tableData.push(['Organization Id', data.organizationId]);
                tableData.push(['Production', data.isProduction ? 'Y' : 'N']);
                tableData.push(['Type', data.type]);
                tableData.push(['Client Id', data.clientId]);
                await this.show(tableData, data);
            }
            else {
                this.error(new Error('Error creating the environment'));
            }
        }
        catch (error) {
            ((_b = (_a = error === null || error === void 0 ? void 0 : error.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.message) ? this.error(error.response.data.message) : this.error(error);
        }
    }
}
exports.default = Create;
Create.args = [
    {
        name: 'name',
        required: true,
    },
];
Create.description = 'Create new environment';
// .option('--type <typeName> ', 'Environment type. Supported Values: ' + envTypes.join(', '), envTypes)
Create.flags = {
    ...anypoint_cli_command_1.AuthenticationBaseCommand.flags,
    help: core_1.Flags.help({ char: 'h' }),
    // flag with the type value
    type: core_1.Flags.string({ char: 't', description: `Environment type. Supported Values: ${[...envTypes].join(', ')}` }),
    ...flags_1.OutputFlag,
};
