"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const anypoint_cli_command_1 = require("anypoint-cli-command");
class Delete extends anypoint_cli_command_1.AuthenticationBaseCommand {
    async run() {
        const { args } = await this.parse(Delete);
        await this.environmentDelete(args.name);
    }
    async environmentDelete(name) {
        const env = await anypoint_cli_command_1.utils.getEnvironmentByName(name);
        if (!env) {
            this.error(new Error(`Environment ${name} not found`));
        }
        const session = this.session;
        const { status } = await this.req.delete(anypoint_cli_command_1.uris.environment(session.selectedOrganization.id, env.id));
        if (status === 204) {
            if (env.id === session.selectedEnvironment.id) {
                const newDefaultEnv = await anypoint_cli_command_1.utils.getDefaultEnvironment();
                anypoint_cli_command_1.default.set('session.selectedEnvironment.id', newDefaultEnv.id);
            }
            this.log(`Environment ${name} deleted successfully`);
        }
        else {
            this.error(new Error(`Error deleting the environment ${name}`));
        }
    }
}
exports.default = Delete;
Delete.args = [
    {
        name: 'name',
        required: true,
    },
];
Delete.description = 'Delete an environment';
Delete.flags = {
    ...anypoint_cli_command_1.AuthenticationBaseCommand.flags,
    help: core_1.Flags.help({ char: 'h' }),
};
